summaryrefslogtreecommitdiffstats
path: root/chromeos/network/network_device_handler_unittest.cc
diff options
context:
space:
mode:
authorbenchan@chromium.org <benchan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-24 07:24:56 +0000
committerbenchan@chromium.org <benchan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-24 07:24:56 +0000
commit547396c5c0ca818ca4ee7a4eb9667669a0898e73 (patch)
treecf5f5d591e4f2482f44532451f1fdfde50601f67 /chromeos/network/network_device_handler_unittest.cc
parent8b44fa5704850a6e891fd25aaaac34b616729df2 (diff)
downloadchromium_src-547396c5c0ca818ca4ee7a4eb9667669a0898e73.zip
chromium_src-547396c5c0ca818ca4ee7a4eb9667669a0898e73.tar.gz
chromium_src-547396c5c0ca818ca4ee7a4eb9667669a0898e73.tar.bz2
Migrate DBus service constants from flimflam namespace to shill namespace.
All shill DBus service constants have been moved from the flimflam namespace to the shill namespace. This CL makes the corresponding changes on the Chrome side. Related CLs: https://chromium-review.googlesource.com/#/c/170123/ https://chromium-review.googlesource.com/#/c/170205/ https://chromium-review.googlesource.com/#/c/170206/ https://chromium-review.googlesource.com/#/c/170207/ https://chromium-review.googlesource.com/#/c/170208/ https://chromium-review.googlesource.com/#/c/170209/ https://chromium-review.googlesource.com/#/c/170223/ https://chromium-review.googlesource.com/#/c/170230/ https://chromium-review.googlesource.com/#/c/170231/ BUG=295425 R=gspencer@chromium.org,gauravsh@chromium.org,stevenjb@chromium.org Review URL: https://chromiumcodereview.appspot.com/24348002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@224942 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chromeos/network/network_device_handler_unittest.cc')
-rw-r--r--chromeos/network/network_device_handler_unittest.cc23
1 files changed, 11 insertions, 12 deletions
diff --git a/chromeos/network/network_device_handler_unittest.cc b/chromeos/network/network_device_handler_unittest.cc
index ff58e6b..dd9667a 100644
--- a/chromeos/network/network_device_handler_unittest.cc
+++ b/chromeos/network/network_device_handler_unittest.cc
@@ -44,20 +44,19 @@ class NetworkDeviceHandlerTest : public testing::Test {
DBusThreadManager::Get()->GetShillDeviceClient()->GetTestInterface();
device_test->ClearDevices();
device_test->AddDevice(
- kDefaultCellularDevicePath, flimflam::kTypeCellular, "cellular1");
- device_test->AddDevice(
- kDefaultWifiDevicePath, flimflam::kTypeWifi, "wifi1");
+ kDefaultCellularDevicePath, shill::kTypeCellular, "cellular1");
+ device_test->AddDevice(kDefaultWifiDevicePath, shill::kTypeWifi, "wifi1");
base::FundamentalValue allow_roaming(false);
device_test->SetDeviceProperty(
kDefaultCellularDevicePath,
- flimflam::kCellularAllowRoamingProperty,
+ shill::kCellularAllowRoamingProperty,
allow_roaming);
base::ListValue test_ip_configs;
test_ip_configs.AppendString("ip_config1");
device_test->SetDeviceProperty(
- kDefaultWifiDevicePath, flimflam::kIPConfigsProperty, test_ip_configs);
+ kDefaultWifiDevicePath, shill::kIPConfigsProperty, test_ip_configs);
}
virtual void TearDown() OVERRIDE {
@@ -170,8 +169,8 @@ TEST_F(NetworkDeviceHandlerTest, GetDeviceProperties) {
message_loop_.RunUntilIdle();
EXPECT_EQ(kResultSuccess, result_);
std::string type;
- properties_->GetString(flimflam::kTypeProperty, &type);
- EXPECT_EQ(flimflam::kTypeWifi, type);
+ properties_->GetString(shill::kTypeProperty, &type);
+ EXPECT_EQ(shill::kTypeWifi, type);
}
TEST_F(NetworkDeviceHandlerTest, SetDeviceProperty) {
@@ -184,15 +183,15 @@ TEST_F(NetworkDeviceHandlerTest, SetDeviceProperty) {
EXPECT_EQ(kResultSuccess, result_);
bool allow_roaming;
EXPECT_TRUE(properties_->GetBooleanWithoutPathExpansion(
- flimflam::kCellularAllowRoamingProperty, &allow_roaming));
+ shill::kCellularAllowRoamingProperty, &allow_roaming));
EXPECT_FALSE(allow_roaming);
// Set the flimflam::kCellularAllowRoamingProperty to true. The call
// should succeed and the value should be set.
base::FundamentalValue allow_roaming_value(true);
network_device_handler_->SetDeviceProperty(
kDefaultCellularDevicePath,
- flimflam::kCellularAllowRoamingProperty,
+ shill::kCellularAllowRoamingProperty,
allow_roaming_value,
success_callback_,
error_callback_);
@@ -207,13 +206,13 @@ TEST_F(NetworkDeviceHandlerTest, SetDeviceProperty) {
message_loop_.RunUntilIdle();
EXPECT_EQ(kResultSuccess, result_);
EXPECT_TRUE(properties_->GetBooleanWithoutPathExpansion(
- flimflam::kCellularAllowRoamingProperty, &allow_roaming));
+ shill::kCellularAllowRoamingProperty, &allow_roaming));
EXPECT_TRUE(allow_roaming);
// Set property on an invalid path.
network_device_handler_->SetDeviceProperty(
"/device/invalid_path",
- flimflam::kCellularAllowRoamingProperty,
+ shill::kCellularAllowRoamingProperty,
allow_roaming_value,
success_callback_,
error_callback_);
@@ -184,15 +183,15 @@ TEST_F(NetworkDeviceHandlerTest, SetDeviceProperty) {
EXPECT_FALSE(allow_roaming);
- // Set the flimflam::kCellularAllowRoamingProperty to true. The call
+ // Set the shill::kCellularAllowRoamingProperty to true. The call
// should succeed and the value should be set.
base::FundamentalValue allow_roaming_value(true);